==> haskell-pretty-show-1.10-13-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-pretty-show.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 pretty-show
version:              1.10
visibility:           public
id:                   pretty-show-1.10-30ddFMLbEm1DQ0GcmAHjnN
key:                  pretty-show-1.10-30ddFMLbEm1DQ0GcmAHjnN
license:              MIT
maintainer:           iavor.diatchki@gmail.com
author:               Iavor S. Diatchki
homepage:             http://wiki.github.com/yav/pretty-show
synopsis:
    Tools for working with derived `Show` instances and generic
    inspection of values.

description:
    We provide a library and an executable for working with derived '\''Show'\''
    instances. By using the library, we can parse derived '\''Show'\'' instances into a
    generic data structure. The @ppsh@ tool uses the library to produce
    human-readable versions of '\''Show'\'' instances, which can be quite handy for
    debugging Haskell programs.  We can also render complex generic values into
    an interactive Html page, for easier examination.

category:             Text
abi:                  0f9a60f1c9b8e3c359e09b5290c65e8b
exposed:              True
exposed-modules:      Text.Show.Pretty
hidden-modules:
    Text.Show.Html Text.Show.Parser Text.Show.Value Text.Show.PrettyVal
    Paths_pretty_show

import-dirs:          /usr/lib/ghc-9.0.2/site-local/pretty-show-1.10
library-dirs:         /usr/lib/ghc-9.0.2/site-local/pretty-show-1.10
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pretty-show
hs-libraries:         HSpretty-show-1.10-30ddFMLbEm1DQ0GcmAHjnN
depends:
    array-0.5.4.0 base-4.15.1.0 filepath-1.4.2.1 ghc-prim-0.7.0
    haskell-lexer-1.1-CfqUww4ysLq8GMrrav0JAz pretty-1.1.3.6
    text-1.2.5.0

haddock-interfaces:   /usr/share/doc/haskell-pretty-show/html/pretty-show.haddock
haddock-html:         /usr/share/doc/haskell-pretty-show/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-pretty-show-1.10-14-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-pretty-show.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 pretty-show
version:              1.10
visibility:           public
id:                   pretty-show-1.10-E9zv3yZn35Y9VpF8wkb8MR
key:                  pretty-show-1.10-E9zv3yZn35Y9VpF8wkb8MR
license:              MIT
maintainer:           iavor.diatchki@gmail.com
author:               Iavor S. Diatchki
homepage:             http://wiki.github.com/yav/pretty-show
synopsis:
    Tools for working with derived `Show` instances and generic
    inspection of values.

description:
    We provide a library and an executable for working with derived '\''Show'\''
    instances. By using the library, we can parse derived '\''Show'\'' instances into a
    generic data structure. The @ppsh@ tool uses the library to produce
    human-readable versions of '\''Show'\'' instances, which can be quite handy for
    debugging Haskell programs.  We can also render complex generic values into
    an interactive Html page, for easier examination.

category:             Text
abi:                  d5da3d9ec87a023b8a66c9c60422de35
exposed:              True
exposed-modules:      Text.Show.Pretty
hidden-modules:
    Text.Show.Html Text.Show.Parser Text.Show.Value Text.Show.PrettyVal
    Paths_pretty_show

import-dirs:          /usr/lib/ghc-9.0.2/site-local/pretty-show-1.10
library-dirs:         /usr/lib/ghc-9.0.2/site-local/pretty-show-1.10
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pretty-show
hs-libraries:         HSpretty-show-1.10-E9zv3yZn35Y9VpF8wkb8MR
depends:
    array-0.5.4.0 base-4.15.1.0 filepath-1.4.2.1 ghc-prim-0.7.0
    haskell-lexer-1.1.1-IRVZOu2KPy1H4iv0SBQFmV pretty-1.1.3.6
    text-1.2.5.0

haddock-interfaces:   /usr/share/doc/haskell-pretty-show/html/pretty-show.haddock
haddock-html:         /usr/share/doc/haskell-pretty-show/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
